Package: quantMSImageR
Title: Processing and Quantification of Targeted Mass Spectrometry
        Imaging Data
Version: 0.99.6
Authors@R: 
    person("Matthew J.", "Smith", , "mattyjsmith123@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7357-2670"))
Description: Implements tools for processing and quantifying targeted
        DESI-MRM mass spectrometry imaging (MSI) datasets, extending
        the Cardinal package. Includes signal-to-noise filtering
        against background pixels, tissue/background separation,
        per-feature ion images, quantile heatmaps, quantification
        against on-slide or on-tissue calibration standards, and batch
        export of per-feature text images for external viewers.
License: MIT + file LICENSE
URL: https://mjs-708.github.io/quantMSImageR,
        https://github.com/MJS-708/quantMSImageR
BugReports: https://github.com/MJS-708/quantMSImageR/issues
biocViews: Software, MassSpectrometry, ImagingMassSpectrometry,
        Metabolomics, Lipidomics, QualityControl, Normalization,
        Visualization
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Depends: R (>= 4.5.0), Cardinal (>= 3.6.2)
Imports: methods, stats, utils, grDevices, grid, chemCal (>= 0.2.3),
        viridis (>= 0.6.5), ComplexHeatmap (>= 2.20.0), circlize (>=
        0.4.15), matrixStats (>= 0.63.0), pracma (>= 2.4.0), rmarkdown
        (>= 2.20), purrr (>= 1.0.0), CardinalIO (>= 1.0.0),
        ProtGenerics (>= 1.34.0), dplyr (>= 1.1.4), ggplot2 (>= 4.0.0),
        tibble (>= 3.2.1), tidyr (>= 1.3.1), patchwork (>= 1.2.0), yaml
        (>= 2.3.0)
Suggests: testthat (>= 3.0.0), knitr (>= 1.40), BiocStyle (>= 2.28.0),
        rstudioapi (>= 0.15.0), DT (>= 0.33), htmltools (>= 0.5.0),
        magick (>= 2.8.4), openxlsx (>= 4.2.0), matter (>= 2.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Collate: 'setClasses.R' 'accessors.R' 'alignFeatures.R' 'applySNR.R'
        'back2NA.R' 'bindPanels.R' 'buildFeatureMeta.R' 'combineMSIs.R'
        'contributionHm.R' 'createCalCurve.R' 'createMSIDataMatrix.R'
        'generateTxtImages.R' 'imageR.R' 'int2SNR.R' 'int2conc.R'
        'int2response.R' 'join_ion_library.R' 'palettes.R'
        'plotCalCoverage.R' 'quantMSImageR-package.R' 'quantileHm.R'
        'readMRM.R' 'removeBlankMzs.R' 'runExample.R' 'runStudy.R'
        'selectTissuePixels.R' 'stitchAcquisitions.R'
        'summariseCalLevels.R' 'trimMSI.R' 'validate.R' 'zero2NA.R'
Config/roxygen2/version: 8.0.0
Config/pak/sysreqs: cmake make libicu-dev libpng-dev libuv1-dev perl
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-08-20 16:00:06 UTC
RemoteUrl: https://github.com/bioc/quantMSImageR
RemoteRef: HEAD
RemoteSha: 6b613f494bec2307501f616b31d6a8a92f4cfa21
NeedsCompilation: no
Packaged: 2026-08-23 15:02:10 UTC; root
Author: Matthew J. Smith [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7357-2670>)
Maintainer: Matthew J. Smith <mattyjsmith123@gmail.com>
Built: R 4.6.1; ; 2026-08-23 15:04:03 UTC; unix
