# Generated by roxygen2: do not edit by hand

S3method(print,quantValidation)
export("calibrationData<-")
export("calibrationModels<-")
export(alignFeatures)
export(bindPanels)
export(buildFeatureMeta)
export(calibrationData)
export(calibrationDiagnostics)
export(calibrationInfo)
export(calibrationLevels)
export(calibrationMetadata)
export(calibrationModels)
export(calibrationR2)
export(contributionHm)
export(generateTxtImages)
export(quantPalettes)
export(quant_MSImagingExperiment)
export(quantileHm)
export(readMRM)
export(runExample)
export(runStudy)
export(selectTissuePixels)
export(stitchAcquisitions)
export(tissueData)
export(tissueInfo)
export(tissueMatrix)
export(trimMSI)
export(validateConfig)
exportClasses(quant_MSImagingExperiment)
exportMethods("calibrationData<-")
exportMethods("calibrationModels<-")
exportMethods(applySNR)
exportMethods(back2NA)
exportMethods(calibrationData)
exportMethods(calibrationDiagnostics)
exportMethods(calibrationLevels)
exportMethods(calibrationMetadata)
exportMethods(calibrationModels)
exportMethods(calibrationR2)
exportMethods(combineMSIs)
exportMethods(createCalCurve)
exportMethods(createMSIDataMatrix)
exportMethods(imageR)
exportMethods(int2SNR)
exportMethods(int2conc)
exportMethods(int2response)
exportMethods(plotCalCoverage)
exportMethods(removeBlankMzs)
exportMethods(show)
exportMethods(summariseCalLevels)
exportMethods(tissueData)
exportMethods(tissueMatrix)
exportMethods(zero2NA)
import(Cardinal)
importFrom(ProtGenerics,"spectraData<-")
importFrom(ProtGenerics,spectraData)
importFrom(chemCal,inverse.predict)
importFrom(circlize,colorRamp2)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,right_join)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_equal)
importFrom(ggplot2,discrete_scale)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,rel)
importFrom(ggplot2,scale_alpha_identity)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.new)
importFrom(grDevices,rainbow)
importFrom(grid,unit)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setValidity)
importFrom(methods,show)
importFrom(methods,validObject)
importFrom(patchwork,wrap_plots)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tibble,column_to_rownames)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_wider)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,write.csv)
importFrom(utils,write.table)
importFrom(viridis,scale_fill_viridis)
importFrom(yaml,read_yaml)
